==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/ResizeContext.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/ResizeContext", ['module', 'exports', 'require', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.useUpdatedLayoutDataContext = exports.useSetUpdatedLayoutDataContext = exports.useSetResizeContext = exports.useResizeContext = exports.ResizeContextProvider = exports.ResizeContext = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    var INITIAL_STATE = {
      resizing: false,
      setCustomRow: function setCustomRow() {
        return null;
      },
      setResizing: function setResizing() {
        return null;
      },
      setUpdatedLayoutData: function setUpdatedLayoutData() {
        return null;
      },
      updatedLayoutData: null
    };

    var ResizeContext = _react["default"].createContext(INITIAL_STATE);

    exports.ResizeContext = ResizeContext;
    var ResizeContextProvider = ResizeContext.Provider;
    exports.ResizeContextProvider = ResizeContextProvider;

    var useResizeContext = function useResizeContext() {
      return (0, _react.useContext)(ResizeContext).resizing;
    };

    exports.useResizeContext = useResizeContext;

    var useSetResizeContext = function useSetResizeContext() {
      return (0, _react.useContext)(ResizeContext).setResizing;
    };

    exports.useSetResizeContext = useSetResizeContext;

    var useSetUpdatedLayoutDataContext = function useSetUpdatedLayoutDataContext() {
      return (0, _react.useContext)(ResizeContext).setUpdatedLayoutData;
    };

    exports.useSetUpdatedLayoutDataContext = useSetUpdatedLayoutDataContext;

    var useUpdatedLayoutDataContext = function useUpdatedLayoutDataContext() {
      return (0, _react.useContext)(ResizeContext).updatedLayoutData;
    };

    exports.useUpdatedLayoutDataContext = useUpdatedLayoutDataContext;
    //# sourceMappingURL=ResizeContext.js.map
  }
});
//# sourceMappingURL=ResizeContext.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/ResizeContext.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/ResizeContext", ['module', 'exports', 'require', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.useUpdatedLayoutDataContext = exports.useSetUpdatedLayoutDataContext = exports.useSetResizeContext = exports.useResizeContext = exports.ResizeContextProvider = exports.ResizeContext = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    var INITIAL_STATE = {
      resizing: false,
      setCustomRow: function setCustomRow() {
        return null;
      },
      setResizing: function setResizing() {
        return null;
      },
      setUpdatedLayoutData: function setUpdatedLayoutData() {
        return null;
      },
      updatedLayoutData: null
    };

    var ResizeContext = /*#__PURE__*/_react.default.createContext(INITIAL_STATE);

    exports.ResizeContext = ResizeContext;
    var ResizeContextProvider = ResizeContext.Provider;
    exports.ResizeContextProvider = ResizeContextProvider;

    var useResizeContext = function useResizeContext() {
      return (0, _react.useContext)(ResizeContext).resizing;
    };

    exports.useResizeContext = useResizeContext;

    var useSetResizeContext = function useSetResizeContext() {
      return (0, _react.useContext)(ResizeContext).setResizing;
    };

    exports.useSetResizeContext = useSetResizeContext;

    var useSetUpdatedLayoutDataContext = function useSetUpdatedLayoutDataContext() {
      return (0, _react.useContext)(ResizeContext).setUpdatedLayoutData;
    };

    exports.useSetUpdatedLayoutDataContext = useSetUpdatedLayoutDataContext;

    var useUpdatedLayoutDataContext = function useUpdatedLayoutDataContext() {
      return (0, _react.useContext)(ResizeContext).updatedLayoutData;
    };

    exports.useUpdatedLayoutDataContext = useUpdatedLayoutDataContext;
    //# sourceMappingURL=ResizeContext.js.map
  }
});
//# sourceMappingURL=ResizeContext.js.map
